@@ -1,20 +1,18 @@
+from __future__ import annotations
+
 import logging
-import re
 import os
+import re
 import time
-
-from zipfile import ZipFile, ZipInfo
+from asyncio.exceptions import TimeoutError
 from io import RawIOBase
-
-from six.moves.urllib.parse import unquote_plus
+from typing import Any
+from urllib.parse import unquote_plus
+from zipfile import ZipFile, ZipInfo
 
 import aiohttp
 from aiohttp.client_exceptions import ClientError
-from asyncio.exceptions import TimeoutError
-
 from asyncblink import signal
-from sanic.response import StreamingHTTPResponse
-
 
 from fpx.model import Ticket
 
@@ -56,7 +54,9 @@ async def stream_ticket(ticket: Ticket, chunk_size: int = chunk_size):
         stream,
         mode="w",
     ) as zf:
-        async for path, name, content in stream_downloaded_files(ticket.items):
+        async for path, name, content, _resp in stream_downloaded_files(
+            ticket.items
+        ):
             z_info = ZipInfo(os.path.join(path, name), time.gmtime()[:6])
             with zf.open(z_info, mode="w", force_zip64=True) as dest:
                 try:
@@ -89,7 +89,7 @@ async def stream_downloaded_files(items):
                 headers = item.get("headers", headers)
             else:
                 url = item
-                name = os.path.basename(url)
+                name = os.path.basename(url.rstrip("/"))
             try:
                 simplified_name = os.path.basename(
                     unquote_plus(unquote_plus(unquote_plus(name)))
@@ -109,7 +109,7 @@ async def stream_downloaded_files(items):
                         match = disposition_re.match(disposition)
                         if match:
                             name = match.group(1)
-                    yield path, name, resp.content
+                    yield path, name, resp.content, resp
             except ClientError:
                 log.exception(f"Failed on {url}")
 
